/*
 * Name: Button Clicker
 * Developer: Vinyl Support
 * Date: 02/06/2024
 */
define(function () {

    var install = function (holderElement, context) {
        var showTimestamp = context.getParameter("ShowTimestamp") == "1";
        var text = context.getParameter("Text");
        var classNames = context.getParameter("ClassNames");
        var interval = parseInt(context.getParameter("Interval"), 10);
        var clickable = context.getParameter("Clickable") == "1";

        var moment = context.loadedDependencies[0];
        
        var testNode = holderElement.childNodes[0];
        
        if (classNames) {
            classNames.split(' ').forEach(function(className) {
                testNode.classList.add(className);
            });
        }
        
        
        var lastRun = moment();

        var setText = function() {
            var content = text;
            if (showTimestamp) {
                content += " " + lastRun.fromNow();
            }
            testNode.innerHTML = content;

            testNode.setAttribute('title', lastRun.toString());
        };

        var setTextTimer = setInterval(setText, 1000);
        
        var wrappedViewModel = context.viewModel;
        
        if (!wrappedViewModel.action.hasAction()) {
            throw new Error("Button Clicker on button without an event or link.");
        }

        var timer = 0;
        
        var runClick = function() {
            if (!document.contains(testNode)) {
                clearInterval(timer);
                clearInterval(setTextTimer);
                return;
            }

            wrappedViewModel.click(wrappedViewModel);

            setText();

            lastRun = moment();
        };
        
        timer = setInterval(runClick, interval);

        if (clickable) {
            testNode.addEventListener("click", runClick);
            testNode.classList.add("vinyl-pointer");
        }
        
    };

    var uninstall = function (holderElement, context) {
        // No implementation
    };

    return {
        callbacks: {
            events: {
                // adding and removing
                install: install,
                uninstall: uninstall
            }
        }
    };
});